function [alpha] = get_lratio(x, pp,xp,pn,xn);
%get_lratio - computes likelihood ratio at x given distribution of positive
%             and negative examples
%
%   [alpha] = get_lratio(x, pp,xp,pn,xn);
%
%    x - (nx1) variable to compute likelihood ratio
%    pp,pn - estimated pdf of a random variable at xp an xn
%
%    alpha - likelihood ratio
%        alpha = pp(x) / pn(x) 
%
%  linear interpolation is used (Gaussian extrapolation)
%

warning('off','MATLAB:divideByZero');

PP = interp1(xp,pp,x); ip = isnan(PP); PP(ip)=0;
PN = interp1(xn,pn,x); in = isnan(PN); PN(in)=0;
alpha = PP./PN;

warning('on','MATLAB:divideByZero');

%GAUSSIAN EXTRAPOLATION
s_p = sqrt(cov(xp)); m_p = mean(xp);
s_n = sqrt(cov(xn)); m_n = mean(xn);

%t=linspace(-3,3,1000);
%P = 1/sqrt(2*pi)/s_p*exp(-(t-m_p).^2/(2*s_p^2)); 
%N = 1/sqrt(2*pi)/s_n*exp(-(t-m_n).^2/(2*s_n^2)); 

i=find(ip|in);
P = 1/sqrt(2*pi)/s_p*exp(-(x(i)-m_p).^2/(2*s_p^2));
N = 1/sqrt(2*pi)/s_n*exp(-(x(i)-m_n).^2/(2*s_n^2));

alpha(i) = P./N;
